@@ -235,6 +235,8 @@ Currently, empty cells show 0.
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE ExtendedDefaultRules #-}
 {-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE TemplateHaskell #-}
+{-# LANGUAGE NamedFieldPuns #-}
 
 module Hledger.Cli.Commands.Balance (
   balancemode
@@ -268,36 +270,33 @@ import Hledger.Read.CsvReader (CSV, printCSV)
 
 
 -- | Command line options for this command.
-balancemode = (defCommandMode $ ["balance"] ++ aliases) { -- also accept but don't show the common bal alias
-  modeHelp = "show accounts and balances" `withAliases` aliases
- ,modeGroupFlags = C.Group {
-     groupUnnamed = [
-      flagNone ["change"] (\opts -> setboolopt "change" opts)
-        "show balance change in each period (default)"
-     ,flagNone ["cumulative"] (\opts -> setboolopt "cumulative" opts)
-        "show balance change accumulated across periods (in multicolumn reports)"
-     ,flagNone ["historical","H"] (\opts -> setboolopt "historical" opts)
-        "show historical ending balance in each period (includes postings before report start date)\n "
-     ,flagNone ["tree"] (\opts -> setboolopt "tree" opts) "show accounts as a tree; amounts include subaccounts (default in simple reports)"
-     ,flagNone ["flat"] (\opts -> setboolopt "flat" opts) "show accounts as a list; amounts exclude subaccounts except when account is depth-clipped (default in multicolumn reports)\n "
-     ,flagNone ["average","A"] (\opts -> setboolopt "average" opts) "show a row average column (in multicolumn reports)"
-     ,flagNone ["row-total","T"] (\opts -> setboolopt "row-total" opts) "show a row total column (in multicolumn reports)"
-     ,flagNone ["no-total","N"] (\opts -> setboolopt "no-total" opts) "omit the final total row"
-     ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "omit N leading account name parts (in flat mode)"
-     ,flagNone ["no-elide"] (\opts -> setboolopt "no-elide" opts) "don't squash boring parent accounts (in tree mode)"
-     ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format (in simple reports)"
-     ,flagNone ["pretty-tables"] (\opts -> setboolopt "pretty-tables" opts) "use unicode to display prettier tables"
-     ,flagNone ["sort-amount","S"] (\opts -> setboolopt "sort-amount" opts) "sort by amount instead of account code/name (in flat mode). With multiple columns, sorts by the row total, or by row average if that is displayed."
-     ,flagNone ["budget"] (setboolopt "budget") "show performance compared to budget goals defined by periodic transactions"
-     ,flagNone ["show-unbudgeted"] (setboolopt "show-unbudgeted") "with --budget, show unbudgeted accounts also"
-     ,flagNone ["invert"] (setboolopt "invert") "display all amounts with reversed sign"
-     ]
-     ++ outputflags
-    ,groupHidden = []
-    ,groupNamed = [generalflagsgroup1]
-    }
- }
-  where aliases = ["b","bal"]
+balancemode = hledgerCommandMode
+  $(embedFileRelative "Hledger/Cli/Commands/Balance.txt")
+  ([flagNone ["change"] (setboolopt "change")
+      "show balance change in each period (default)"
+   ,flagNone ["cumulative"] (setboolopt "cumulative")
+      "show balance change accumulated across periods (in multicolumn reports)"
+   ,flagNone ["historical","H"] (setboolopt "historical")
+      "show historical ending balance in each period (includes postings before report start date)\n "
+   ,flagNone ["tree"] (setboolopt "tree") "show accounts as a tree; amounts include subaccounts (default in simple reports)"
+   ,flagNone ["flat"] (setboolopt "flat") "show accounts as a list; amounts exclude subaccounts except when account is depth-clipped (default in multicolumn reports)\n "
+   ,flagNone ["average","A"] (setboolopt "average") "show a row average column (in multicolumn reports)"
+   ,flagNone ["row-total","T"] (setboolopt "row-total") "show a row total column (in multicolumn reports)"
+   ,flagNone ["no-total","N"] (setboolopt "no-total") "omit the final total row"
+   ,flagReq  ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "omit N leading account name parts (in flat mode)"
+   ,flagNone ["no-elide"] (setboolopt "no-elide") "don't squash boring parent accounts (in tree mode)"
+   ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format (in simple reports)"
+   ,flagNone ["pretty-tables"] (setboolopt "pretty-tables") "use unicode to display prettier tables"
+   ,flagNone ["sort-amount","S"] (setboolopt "sort-amount") "sort by amount instead of account code/name (in flat mode). With multiple columns, sorts by the row total, or by row average if that is displayed."
+   ,flagNone ["budget"] (setboolopt "budget") "show performance compared to budget goals defined by periodic transactions"
+   ,flagNone ["invert"] (setboolopt "invert") "display all amounts with reversed sign"
+   ,flagNone ["transpose"] (setboolopt "transpose") "transpose rows and columns"
+   ]
+   ++ outputflags
+  )
+  [generalflagsgroup1]
+  []
+  ([], Just $ argsFlag "[QUERY]")
 
 -- | The balance command, prints a balance report.
 balance :: CliOpts -> Journal -> IO ()
@@ -313,9 +312,8 @@ balance opts@CliOpts{rawopts_=rawopts,reportopts_=ropts} j = do
         (True, _) -> do
           -- single or multicolumn budget report
           reportspan <- reportSpan j ropts
-          let budgetreport     = dbg1 "budgetreport"     $ budgetReport ropts assrt showunbudgeted reportspan d j
+          let budgetreport     = dbg1 "budgetreport"     $ budgetReport ropts assrt reportspan d j
                 where
-                  showunbudgeted = boolopt "show-unbudgeted" rawopts
                   assrt          = not $ ignore_assertions_ $ inputopts_ opts
               render = case format of
                 "csv"  -> const $ error' "Sorry, CSV output is not yet implemented for this kind of report."  -- TODO
@@ -468,27 +466,31 @@ renderComponent1 opts (acctname, depth, total) (FormatField ljust min max field)
 -- The CSV will always include the initial headings row,
 -- and will include the final totals row unless --no-total is set.
 multiBalanceReportAsCsv :: ReportOpts -> MultiBalanceReport -> CSV
-multiBalanceReportAsCsv opts (MultiBalanceReport (colspans, items, (coltotals,tot,avg))) =
+multiBalanceReportAsCsv opts@ReportOpts{average_, row_total_} (MultiBalanceReport (colspans, items, (coltotals,tot,avg))) =
+  maybetranspose $ 
   ("Account" : map showDateSpan colspans
-   ++ (if row_total_ opts then ["Total"] else [])
-   ++ (if average_ opts then ["Average"] else [])
+   ++ ["Total"   | row_total_]
+   ++ ["Average" | average_]
   ) :
   [T.unpack (maybeAccountNameDrop opts a) :
    map showMixedAmountOneLineWithoutPrice
    (amts
-    ++ (if row_total_ opts then [rowtot] else [])
-    ++ (if average_ opts then [rowavg] else []))
+    ++ [rowtot | row_total_]
+    ++ [rowavg | average_])
   | (a, _, _, amts, rowtot, rowavg) <- items]
   ++
   if no_total_ opts
   then []
-  else [["Total:"]
-        ++ map showMixedAmountOneLineWithoutPrice (
-           coltotals
-           ++ (if row_total_ opts then [tot] else [])
-           ++ (if average_ opts then [avg] else [])
-           )]
-
+  else ["Total:" :
+        map showMixedAmountOneLineWithoutPrice (
+          coltotals
+          ++ [tot | row_total_]
+          ++ [avg | average_]
+          )]
+  where
+    maybetranspose | transpose_ opts = transpose
+                   | otherwise = id
+    
 -- | Render a multi-column balance report as HTML.
 multiBalanceReportAsHtml :: ReportOpts -> MultiBalanceReport -> Html ()
 multiBalanceReportAsHtml ropts mbr =
@@ -498,14 +500,15 @@ multiBalanceReportAsHtml ropts mbr =
     table_ $ mconcat $
          [headingsrow]
       ++ bodyrows
-      ++ maybe [] (:[]) mtotalsrow
+      ++ maybeToList mtotalsrow
 
 -- | Render the HTML table rows for a MultiBalanceReport.
 -- Returns the heading row, 0 or more body rows, and the totals row if enabled.
 multiBalanceReportHtmlRows :: ReportOpts -> MultiBalanceReport -> (Html (), [Html ()], Maybe (Html ()))
 multiBalanceReportHtmlRows ropts mbr =
   let
-    headingsrow:rest = multiBalanceReportAsCsv ropts mbr
+    headingsrow:rest | transpose_ ropts = error' "Sorry, --transpose is not supported with HTML output yet"
+                     | otherwise = multiBalanceReportAsCsv ropts mbr
     (bodyrows, mtotalsrow) | no_total_ ropts = (rest,      Nothing)
                            | otherwise       = (init rest, Just $ last rest)
   in
@@ -591,7 +594,8 @@ multiBalanceReportAsText opts r =
 
 -- | Build a 'Table' from a multi-column balance report.
 balanceReportAsTable :: ReportOpts -> MultiBalanceReport -> Table String String MixedAmount
-balanceReportAsTable opts (MultiBalanceReport (colspans, items, (coltotals,tot,avg))) =
+balanceReportAsTable opts@ReportOpts{average_, row_total_} (MultiBalanceReport (colspans, items, (coltotals,tot,avg))) =
+   maybetranspose $
    addtotalrow $ 
    Table
      (T.Group NoLine $ map Header accts)
@@ -602,22 +606,24 @@ balanceReportAsTable opts (MultiBalanceReport (colspans, items, (coltotals,tot,a
        PeriodChange -> showDateSpanMonthAbbrev
        _            -> maybe "" (showDate . prevday) . spanEnd
     colheadings = map mkDate colspans
-                  ++ (if row_total_ opts then ["  Total"] else [])
-                  ++ (if average_ opts then ["Average"] else [])
+                  ++ ["  Total" | row_total_]
+                  ++ ["Average" | average_]
     accts = map renderacct items
     renderacct (a,a',i,_,_,_)
       | tree_ opts = replicate ((i-1)*2) ' ' ++ T.unpack a'
       | otherwise  = T.unpack $ maybeAccountNameDrop opts a
     rowvals (_,_,_,as,rowtot,rowavg) = as
-                             ++ (if row_total_ opts then [rowtot] else [])
-                             ++ (if average_ opts then [rowavg] else [])
+                             ++ [rowtot | row_total_]
+                             ++ [rowavg | average_]
     addtotalrow | no_total_ opts = id
                 | otherwise      = (+----+ (row "" $
                                     coltotals
-                                    ++ (if row_total_ opts && not (null coltotals) then [tot] else [])
-                                    ++ (if average_ opts && not (null coltotals)   then [avg] else [])
+                                    ++ [tot | row_total_ && not (null coltotals)]
+                                    ++ [avg | average_   && not (null coltotals)]
                                     ))
-
+    maybetranspose | transpose_ opts = \(Table rh ch vals) -> Table ch rh (transpose vals)
+                   | otherwise       = id
+                   
 -- | Given a table representing a multi-column balance report (for example,
 -- made using 'balanceReportAsTable'), render it in a format suitable for
 -- console output.
