@@ -1,28 +1,20 @@
-{-# LANGUAGE QuasiQuotes #-}
 {-# LANGUAGE NoOverloadedStrings #-} -- prevent trouble if turned on in ghci
+{-# LANGUAGE TemplateHaskell #-}
 
 module Hledger.Cli.Commands.Checkdates (
   checkdatesmode
  ,checkdates
 ) where
 
-import Data.String.Here
 import Hledger
 import Hledger.Cli.CliOptions
 import System.Console.CmdArgs.Explicit
 import Text.Printf
 
--- checkdatesmode :: Mode RawOpts
+checkdatesmode :: Mode RawOpts
 checkdatesmode = hledgerCommandMode
-  [here| check-dates
-Check that transactions are sorted by increasing date.
-With --date2, checks secondary dates instead.
-With --strict, dates must also be unique.
-With a query, only matched transactions' dates are checked.
-Reads the default journal file, or another specified with -f.
-FLAGS
-  |]
-  [flagNone ["strict"] (\opts -> setboolopt "strict" opts) "makes date comparing strict"]
+  $(embedFileRelative "Hledger/Cli/Commands/Checkdates.txt")
+  [flagNone ["strict"] (setboolopt "strict") "makes date comparing strict"]
   [generalflagsgroup1]
   []
   ([], Just $ argsFlag "[QUERY]")
@@ -69,11 +61,10 @@ foldWhile fold acc (a:as) =
 
 checkTransactions :: (Transaction -> Transaction -> Bool)
  -> [Transaction] -> FoldAcc Transaction Transaction
-checkTransactions compare ts =
-  foldWhile fold FoldAcc{fa_error=Nothing, fa_previous=Nothing} ts
+checkTransactions compare = foldWhile f FoldAcc{fa_error=Nothing, fa_previous=Nothing}
   where
-    fold current acc@FoldAcc{fa_previous=Nothing} = acc{fa_previous=Just current}
-    fold current acc@FoldAcc{fa_previous=Just previous} =
+    f current acc@FoldAcc{fa_previous=Nothing} = acc{fa_previous=Just current}
+    f current acc@FoldAcc{fa_previous=Just previous} =
       if compare previous current
       then acc{fa_previous=Just current}
       else acc{fa_error=Just current}
