@@ -5,6 +5,7 @@ A ledger-compatible @print@ command.
 -}
 
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE TemplateHaskell #-}
 
 module Hledger.Cli.Commands.Print (
   printmode
@@ -25,24 +26,19 @@ import Hledger.Cli.Utils
 import Hledger.Cli.Commands.Add ( transactionsSimilarTo )
 
 
-printmode = (defCommandMode $ ["print"] ++ aliases) {
-  modeHelp = "show transaction journal entries, sorted by date. With --date2, sort by secondary date instead." `withAliases` aliases
- ,modeGroupFlags = Group {
-     groupUnnamed = [
-         let arg = "STR" in
-         flagReq  ["match","m"] (\s opts -> Right $ setopt "match" s opts) arg
-          ("show the transaction whose description is most similar to "++arg++", and is most recent")
-        ,flagNone ["explicit","x"] (setboolopt "explicit")
-          "show all amounts explicitly"
-        ,flagNone ["new"] (setboolopt "new")
-          "show only newer-dated transactions added in each file since last run"
-        ]
-        ++ outputflags
-    ,groupHidden = []
-    ,groupNamed = [generalflagsgroup1]
-    }
- }
-  where aliases = ["p","txns"]
+printmode = hledgerCommandMode
+  $(embedFileRelative "Hledger/Cli/Commands/Print.txt")
+  ([let arg = "STR" in
+   flagReq  ["match","m"] (\s opts -> Right $ setopt "match" s opts) arg
+    ("show the transaction whose description is most similar to "++arg++", and is most recent")
+  ,flagNone ["explicit","x"] (setboolopt "explicit")
+    "show all amounts explicitly"
+  ,flagNone ["new"] (setboolopt "new")
+    "show only newer-dated transactions added in each file since last run"
+  ] ++ outputflags)
+  [generalflagsgroup1]
+  []
+  ([], Just $ argsFlag "[QUERY]")
 
 -- | Print journal transactions in standard format.
 print' :: CliOpts -> Journal -> IO ()
@@ -70,10 +66,7 @@ entriesReportAsText opts = concatMap (showTransactionUnelided . gettxn)
     -- Original vs inferred transactions/postings were causing problems here, disabling -B (#551).
     -- Use the explicit one if -B or -x are active.
     -- This passes tests; does it also mean -B sometimes shows missing amounts unnecessarily ?  
-    useexplicittxn = or
-      [ boolopt "explicit" $ rawopts_ opts
-      , cost_ $ reportopts_ opts
-      ]
+    useexplicittxn = boolopt "explicit" (rawopts_ opts) || cost_ (reportopts_ opts)
 
 -- Replace this transaction's postings with the original postings if any, but keep the
 -- current possibly rewritten account names.
@@ -151,7 +144,7 @@ postingToCSV p =
     let commodity = T.unpack c in
     let credit = if q < 0 then showAmount $ negate a_ else "" in
     let debit  = if q >= 0 then showAmount a_ else "" in
-    account:amount:commodity:credit:debit:status:comment:[])
+    [account, amount, commodity, credit, debit, status, comment])
    amounts
   where
     Mixed amounts = pamount p
