@@ -61,19 +61,19 @@ import Hledger.Utils
 -- | Parse the user's specified journal file(s) as a Journal, maybe apply some
 -- transformations according to options, and run a hledger command with it. 
 -- Or, throw an error.
-withJournalDo :: CliOpts -> (CliOpts -> Journal -> IO ()) -> IO ()
+withJournalDo :: CliOpts -> (Journal -> IO a) -> IO a
 withJournalDo opts cmd = do
   -- We kludgily read the file before parsing to grab the full text, unless
   -- it's stdin, or it doesn't exist and we are adding. We read it strictly
   -- to let the add command work.
   journalpaths <- journalFilePathFromOpts opts
-  readJournalFiles (inputopts_ opts) journalpaths 
+  readJournalFiles (inputopts_ opts) journalpaths
   >>= mapM (journalTransform opts)
-  >>= either error' (cmd opts)
+  >>= either error' cmd
 
 -- | Apply some transformations to the journal if specified by options.
 -- These include:
--- 
+--
 -- - adding forecast transactions (--forecast)
 -- - converting amounts to market value (--value)
 -- - pivoting account names (--pivot)
@@ -106,7 +106,7 @@ anonymise j
       pAnons p = p { paccount = T.intercalate (T.pack ":") . map anon . T.splitOn (T.pack ":") . paccount $ p
                    , pcomment = T.empty
                    , ptransaction = fmap tAnons . ptransaction $ p
-                   , porigin = pAnons <$> porigin p
+                   , poriginal = pAnons <$> poriginal p
                    }
       tAnons txn = txn { tpostings = map pAnons . tpostings $ txn
                        , tdescription = anon . tdescription $ txn
@@ -140,7 +140,7 @@ journalApplyValue ropts j = do
 -- They end on or before the specified report end date, or 180 days from today if unspecified.
 --
 journalAddForecast :: CliOpts -> Journal -> IO Journal
-journalAddForecast opts@CliOpts{reportopts_=ropts} j = do
+journalAddForecast opts@CliOpts{inputopts_=iopts, reportopts_=ropts} j = do
   today <- getCurrentDay
 
   -- "They start on or after the day following the latest normal transaction in the journal, or today if there are none."
@@ -152,13 +152,17 @@ journalAddForecast opts@CliOpts{reportopts_=ropts} j = do
   let forecastend = dbg2 "forecastend" $ fromMaybe (addDays 180 today) mspecifiedend
 
   let forecastspan = DateSpan (Just forecaststart) (Just forecastend)
-      forecasttxns = [ txnTieKnot t | pt <- jperiodictxns j
-                                    , t <- runPeriodicTransaction pt forecastspan
-                                    , spanContainsDate forecastspan (tdate t)
-                                    ]
+      forecasttxns =
+        [ txnTieKnot t | pt <- jperiodictxns j
+                       , t <- runPeriodicTransaction pt forecastspan
+                       , spanContainsDate forecastspan (tdate t)
+                       ]
+      -- With --auto enabled, transaction modifiers are also applied to forecast txns
+      forecasttxns' = (if auto_ iopts then modifyTransactions (jtxnmodifiers j) else id) forecasttxns
+
   return $
     if forecast_ ropts 
-      then journalBalanceTransactions' opts j{ jtxns = forecasttxns ++ jtxns j }  -- XXX wouldn't appending be better ?
+      then journalBalanceTransactions' opts j{ jtxns = concat [jtxns j, forecasttxns'] }
       else j
   where      
     journalBalanceTransactions' opts j =
